Welcome to ModernGL's documentation!
====================================

.. figure:: Examples/images/02_uniforms_and_attributes.png
	:scale: 50 %
	:alt: ModernGL
	:align: center
	:figclass: align-center

Start `here <ModernGL.html>`_.

.. toctree::
   :maxdepth: 4
   :caption: Contents:

   ModernGL <ModernGL.rst>
   Examples <Examples.rst>
   Tutorials <Tutorials.rst>
   Contributing <Contributing.rst>

   TL;DR <TLDR.rst>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
